@@ -6,7 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.47';
+our $VERSION = '0.48';
 
 use File::Copy;
 use File::Path;
@@ -390,7 +390,7 @@ If the user enters C<1>, C<2> or C<3>, the corresponding text string
 C<pick()>.
 
 If the optional C<$opts> hash has C<{ tty =E<gt> 1 }> set, then 
-the user reponse will be expected from the console, not STDIN.
+the user response will be expected from the console, not STDIN.
 
 =cut
 
@@ -440,7 +440,7 @@ Ask the user to either hit I<Enter> and select the displayed default
 or to type in another string.
 
 If the optional C<$opts> hash has C<{ tty =E<gt> 1 }> set, then 
-the user reponse will be expected from the console, not STDIN.
+the user response will be expected from the console, not STDIN.
 
 =cut
 
@@ -471,8 +471,11 @@ sub user_prompt {
 
     $opts = {} if !defined $opts;
 
-    my $fh = *STDERR;
+    my $fh     = *STDERR;
+    my $old_stderr;
     if( $opts->{ tty } ) {
+        open $old_stderr, ">&", \*STDERR or
+            die "Can't dup STDERR: $!";
         open $fh, ">>", '/dev/tty' or 
             die "Cannot open /dev/tty ($!)";
     }
@@ -482,6 +485,8 @@ sub user_prompt {
 
     if( $opts->{ tty } ) {
         close $fh;
+        open STDERR, ">&", $old_stderr or 
+            die "Can't reset STDERR";
     }
 
     return 1;
@@ -892,10 +897,10 @@ sub slurp {
 
 =pod
 
-=item C<blurt($data, $file, $append)>
+=item C<blurt($data, $file, $options)>
 
-Opens a new file, prints the data in C<$data> to it and closes the file.
-If C<$append> is set to a true value, data will be appended to the
+Opens a new file, prints the data in C<$data> to it and closes the file.  If
+C<$options-E<gt>{append}> is set to a true value, data will be appended to the
 file. Default is false, existing files will be overwritten.
 
 If the string is a Unicode string, use the C<utf8> option:
